@@ -54,7 +54,7 @@ class ChattyAssetCollectionInterface(Generic[T, P], ABC):
         if result.matched_count == 0:
             raise NotFoundError(f"No document found with id {asset.id}")
         if result.modified_count == 0:
-            raise ValueError(f"No changes were made to the document with id {asset.id} probably because the values were the same")
+            logger.debug(f"No changes were made to the document with id {asset.id} probably because the values were the same")
         return asset.id
 
     def get_by_id(self, doc_id: str) -> T:
