@@ -3,7 +3,7 @@ from pydantic import BaseModel, Field, field_validator, ValidationInfo, model_va
 from zoneinfo import ZoneInfo
 from typing import List, Dict, Optional, Any
 from datetime import datetime
-
+from enum import StrEnum
 from ....utils.types.message_types import MessageType, MessageSubtype
 from ..schema import ChattyContent, ChattyContext, ChattyContentText, ChattyContentImage, ChattyContentVideo, ChattyContentDocument, ChattyContentSticker, ChattyContentAudio, ChattyContentContacts, ChattyContentLocation, ChattyContentCentral, ChattyContentReaction
 
@@ -22,6 +22,7 @@ class MessageDraft(BaseModel):
         if isinstance(v,ChattyContent):
             return v
         message_type = values.data.get('type')
+        message_type = MessageType(message_type)
         content_class = {
             MessageType.TEXT: ChattyContentText,
             MessageType.IMAGE: ChattyContentImage,
