@@ -6,6 +6,7 @@ class Area(StrEnum):
     ARCHIVED = "ARCHIVED"
     BLOCKED = "BLOCKED"
     INBOX = "INBOX"
+    FOLLOW_UP = "FOLLOW UP"
 
     @classmethod
     def list_all(cls) -> list[str]:
@@ -15,10 +16,12 @@ frontend_areas_to_backend_areas = {
     "esperando agente": Area.WAITING_AGENT,
     "asignar a agente": Area.WITH_AGENT,
     "con agente": Area.WITH_AGENT,
-    "archivados": Area.ARCHIVED
+    "archivados": Area.ARCHIVED,
+    "seguimiento": Area.FOLLOW_UP
 }
 backend_areas_to_frontend_areas = {
     Area.WAITING_AGENT: "esperando agente",
     Area.WITH_AGENT: "con agente",
-    Area.ARCHIVED: "archivados"
+    Area.ARCHIVED: "archivados",
+    Area.FOLLOW_UP: "seguimiento"
 }
\ No newline at end of file
