@@ -5,7 +5,7 @@ from letschatty.models.company.assets.ai_agents.chatty_ai_agent import ChattyAIA
 from letschatty.models.company.assets.ai_agents.chain_of_thought_in_chat import ChainOfThoughtInChatTrigger
 from letschatty.models.company.assets.ai_agents.chatty_ai_mode import ChattyAIMode
 from letschatty.models.company.assets.ai_agents.faq import FAQ
-from letschatty.services.ai_agents.relevant_context_picker import RelevantContextPicker
+# from letschatty.services.ai_agents.relevant_context_picker import RelevantContextPicker
 from letschatty.models.company.assets.ai_agents.context_item import ContextItem
 from letschatty.models.company.empresa import EmpresaModel
 from datetime import datetime
@@ -42,7 +42,7 @@ class ContextBuilder:
     def relevant_contexts(contexts: List[ContextItem], chat:Chat) -> str:
         context = ""
         for context_item in contexts:
-            if RelevantContextPicker.should_be_used(context_item, chat):
+            if True:# RelevantContextPicker.should_be_used(context_item, chat):
                 context += f"\n\n{context_item.title}: {context_item.content}"
         return context
 
@@ -50,7 +50,7 @@ class ContextBuilder:
     def relevant_faqs(faqs: List[FAQ], chat:Chat) -> str:
         context = f"\n\nHere are the FAQ:"
         for faq_index, faq in enumerate(faqs):
-            if RelevantContextPicker.should_be_used(faq, chat):
+            if True:# RelevantContextPicker.should_be_used(faq, chat):
                 context += f"\n{faq_index + 1}. user: {faq.question}\nAI: {faq.answer}"
         return context
 
@@ -58,7 +58,7 @@ class ContextBuilder:
     def relevant_examples(examples: List[ChatExample], chat:Chat) -> str:
         context = f"\n\nHere are the examples of how you should reason (chain of thought) based on the user's messages and answer accordingly. This is the type of reasoning you're expected to do and add to your answer's chain of thought."
         for example_index, example in enumerate(examples):
-            if RelevantContextPicker.should_be_used(example, chat):
+            if True:# RelevantContextPicker.should_be_used(example, chat):
                 context += f"\n{example_index + 1}. {example.title}\n"
                 for element in example.content:
                     context += f"\n{element.type.value}: {element.content}"
